==> ejc-supbid-api-3.0.1-20230707.021729-221-sources.jar: com/ejianc/business/supbid/sub/vo/SubDetailVO.java <==
package com.ejianc.business.supbid.sub.vo;

import java.math.*;
import com.ejianc.framework.skeleton.template.BaseVO;
import io.swagger.annotations.ApiModel;
import io.swagger.annotations.ApiModelProperty;


/**
 * 分包招标采购清单
 * 
 * @author generator
 * 
 */
@ApiModel("分包招标采购清单")
public class SubDetailVO extends BaseVO {
    private static final long serialVersionUID = 1L;
    
    @ApiModelProperty("来源数据Id")
    private Long sourceId;
    @ApiModelProperty("公告ID")
    private Long noticeId;
    @ApiModelProperty("招标采购清单ID")
    private String sourceDetailId;
    @ApiModelProperty("清单编号")
    private String detailCode;
    @ApiModelProperty("清单名称")
    private String detailName;
    @ApiModelProperty("工作内容")
    private String content;
    @ApiModelProperty("计量规则")
    private String rule;
    @ApiModelProperty("单位")
    private String unit;
    @ApiModelProperty("本次计划工程量")
    private BigDecimal num;
    @ApiModelProperty("税率")
    private BigDecimal rate;
    @ApiModelProperty("单价(无税）")
    private BigDecimal price;
    @ApiModelProperty("单价(含税）")
    private BigDecimal taxPrice;
    @ApiModelProperty("金额(无税）")
    private BigDecimal mny;
    @ApiModelProperty("金额(含税）")
    private BigDecimal taxMny;
    @ApiModelProperty("税额")
    private BigDecimal tax;
    @ApiModelProperty("备注")
    private String memo;
    @ApiModelProperty("招标控制单价(无税）")
    private BigDecimal tenderPrice;
    @ApiModelProperty("招标控制单价(含税）")
    private BigDecimal tenderTaxPrice;
    @ApiModelProperty("招标控制金额(无税）")
    private BigDecimal tenderMny;
    @ApiModelProperty("招标控制金额(含税）")
    private BigDecimal tenderTaxMny;
    @ApiModelProperty("信息价")
    private java.math.BigDecimal infoPrice;


    public BigDecimal getInfoPrice() {
        return infoPrice;
    }

    public void setInfoPrice(BigDecimal infoPrice) {
        this.infoPrice = infoPrice;
    }

    public BigDecimal getTenderPrice() {
        return tenderPrice;
    }

    public void setTenderPrice(BigDecimal tenderPrice) {
        this.tenderPrice = tenderPrice;
    }

    public BigDecimal getTenderTaxPrice() {
        return tenderTaxPrice;
    }

    public void setTenderTaxPrice(BigDecimal tenderTaxPrice) {
        this.tenderTaxPrice = tenderTaxPrice;
    }

    public BigDecimal getTenderMny() {
        return tenderMny;
    }

    public void setTenderMny(BigDecimal tenderMny) {
        this.tenderMny = tenderMny;
    }

    public BigDecimal getTenderTaxMny() {
        return tenderTaxMny;
    }

    public void setTenderTaxMny(BigDecimal tenderTaxMny) {
        this.tenderTaxMny = tenderTaxMny;
    }

    /**
     * 来源数据Id
     */
    public Long getSourceId() {
        return sourceId;
    }

    /**
     * 来源数据Id
     */
    public void setSourceId(Long sourceId) {
        this.sourceId = sourceId;
    }
    /**
     * 公告ID
     */
    public Long getNoticeId() {
        return noticeId;
    }

    /**
     * 公告ID
     */
    public void setNoticeId(Long noticeId) {
        this.noticeId = noticeId;
    }
    /**
     * 招标采购清单ID
     */
    public String getSourceDetailId() {
        return sourceDetailId;
    }

    /**
     * 招标采购清单ID
     */
    public void setSourceDetailId(String sourceDetailId) {
        this.sourceDetailId = sourceDetailId;
    }

    /**
     * 清单编号
     */
    public String getDetailCode() {
        return detailCode;
    }

    /**
     * 清单编号
     */
    public void setDetailCode(String detailCode) {
        this.detailCode = detailCode;
    }
    /**
     * 清单名称
     */
    public String getDetailName() {
        return detailName;
    }

    /**
     * 清单名称
     */
    public void setDetailName(String detailName) {
        this.detailName = detailName;
    }
    /**
     * 工作内容
     */
    public String getContent() {
        return content;
    }

    /**
     * 工作内容
     */
    public void setContent(String content) {
        this.content = content;
    }
    /**
     * 计量规则
     */
    public String getRule() {
        return rule;
    }

    /**
     * 计量规则
     */
    public void setRule(String rule) {
        this.rule = rule;
    }
    /**
     * 单位
     */
    public String getUnit() {
        return unit;
    }

    /**
     * 单位
     */
    public void setUnit(String unit) {
        this.unit = unit;
    }
    /**
     * 本次计划工程量
     */
    public BigDecimal getNum() {
        return num;
    }

    /**
     * 本次计划工程量
     */
    public void setNum(BigDecimal num) {
        this.num = num;
    }

    public BigDecimal getRate() {
        return rate;
    }

    public void setRate(BigDecimal rate) {
        this.rate = rate;
    }

    /**
     * 单价(无税）
     */
    public BigDecimal getPrice() {
        return price;
    }

    /**
     * 单价(无税）
     */
    public void setPrice(BigDecimal price) {
        this.price = price;
    }
    /**
     * 单价(含税）
     */
    public BigDecimal getTaxPrice() {
        return taxPrice;
    }

    /**
     * 单价(含税）
     */
    public void setTaxPrice(BigDecimal taxPrice) {
        this.taxPrice = taxPrice;
    }
    /**
     * 金额(无税）
     */
    public BigDecimal getMny() {
        return mny;
    }

    /**
     * 金额(无税）
     */
    public void setMny(BigDecimal mny) {
        this.mny = mny;
    }
    /**
     * 金额(含税）
     */
    public BigDecimal getTaxMny() {
        return taxMny;
    }

    /**
     * 金额(含税）
     */
    public void setTaxMny(BigDecimal taxMny) {
        this.taxMny = taxMny;
    }
    /**
     * 税额
     */
    public BigDecimal getTax() {
        return tax;
    }

    /**
     * 税额
     */
    public void setTax(BigDecimal tax) {
        this.tax = tax;
    }
    /**
     * 备注
     */
    public String getMemo() {
        return memo;
    }

    /**
     * 备注
     */
    public void setMemo(String memo) {
        this.memo = memo;
    }
    
}

==> ejc-supbid-api-3.0.1-20240802.091031-271-sources.jar: com/ejianc/business/supbid/sub/vo/SubDetailVO.java <==
package com.ejianc.business.supbid.sub.vo;

import java.math.*;
import com.ejianc.framework.skeleton.template.BaseVO;
import io.swagger.annotations.ApiModel;
import io.swagger.annotations.ApiModelProperty;


/**
 * 分包招标采购清单
 * 
 * @author generator
 * 
 */
@ApiModel("分包招标采购清单")
public class SubDetailVO extends BaseVO {
    private static final long serialVersionUID = 1L;
    
    @ApiModelProperty("来源数据Id")
    private Long sourceId;
    @ApiModelProperty("公告ID")
    private Long noticeId;
    @ApiModelProperty("招标采购清单ID")
    private String sourceDetailId;
    @ApiModelProperty("清单编号")
    private String detailCode;
    @ApiModelProperty("清单名称")
    private String detailName;
    @ApiModelProperty("工作内容")
    private String content;
    @ApiModelProperty("计量规则")
    private String rule;
    @ApiModelProperty("单位")
    private String unit;
    @ApiModelProperty("本次计划工程量")
    private BigDecimal num;
    @ApiModelProperty("税率")
    private BigDecimal rate;
    @ApiModelProperty("单价(无税）")
    private BigDecimal price;
    @ApiModelProperty("单价(含税）")
    private BigDecimal taxPrice;
    @ApiModelProperty("金额(无税）")
    private BigDecimal mny;
    @ApiModelProperty("金额(含税）")
    private BigDecimal taxMny;
    @ApiModelProperty("税额")
    private BigDecimal tax;
    @ApiModelProperty("备注")
    private String memo;
    @ApiModelProperty("招标控制单价(无税）")
    private BigDecimal tenderPrice;
    @ApiModelProperty("招标控制单价(含税）")
    private BigDecimal tenderTaxPrice;
    @ApiModelProperty("招标控制金额(无税）")
    private BigDecimal tenderMny;
    @ApiModelProperty("招标控制金额(含税）")
    private BigDecimal tenderTaxMny;
    private String materialEquipmentSupply; // 材料设备供应


    public String getMaterialEquipmentSupply() {
        return materialEquipmentSupply;
    }

    public void setMaterialEquipmentSupply(String materialEquipmentSupply) {
        this.materialEquipmentSupply = materialEquipmentSupply;
    }
    public BigDecimal getTenderPrice() {
        return tenderPrice;
    }

    public void setTenderPrice(BigDecimal tenderPrice) {
        this.tenderPrice = tenderPrice;
    }

    public BigDecimal getTenderTaxPrice() {
        return tenderTaxPrice;
    }

    public void setTenderTaxPrice(BigDecimal tenderTaxPrice) {
        this.tenderTaxPrice = tenderTaxPrice;
    }

    public BigDecimal getTenderMny() {
        return tenderMny;
    }

    public void setTenderMny(BigDecimal tenderMny) {
        this.tenderMny = tenderMny;
    }

    public BigDecimal getTenderTaxMny() {
        return tenderTaxMny;
    }

    public void setTenderTaxMny(BigDecimal tenderTaxMny) {
        this.tenderTaxMny = tenderTaxMny;
    }

    /**
     * 来源数据Id
     */
    public Long getSourceId() {
        return sourceId;
    }

    /**
     * 来源数据Id
     */
    public void setSourceId(Long sourceId) {
        this.sourceId = sourceId;
    }
    /**
     * 公告ID
     */
    public Long getNoticeId() {
        return noticeId;
    }

    /**
     * 公告ID
     */
    public void setNoticeId(Long noticeId) {
        this.noticeId = noticeId;
    }
    /**
     * 招标采购清单ID
     */
    public String getSourceDetailId() {
        return sourceDetailId;
    }

    /**
     * 招标采购清单ID
     */
    public void setSourceDetailId(String sourceDetailId) {
        this.sourceDetailId = sourceDetailId;
    }

    /**
     * 清单编号
     */
    public String getDetailCode() {
        return detailCode;
    }

    /**
     * 清单编号
     */
    public void setDetailCode(String detailCode) {
        this.detailCode = detailCode;
    }
    /**
     * 清单名称
     */
    public String getDetailName() {
        return detailName;
    }

    /**
     * 清单名称
     */
    public void setDetailName(String detailName) {
        this.detailName = detailName;
    }
    /**
     * 工作内容
     */
    public String getContent() {
        return content;
    }

    /**
     * 工作内容
     */
    public void setContent(String content) {
        this.content = content;
    }
    /**
     * 计量规则
     */
    public String getRule() {
        return rule;
    }

    /**
     * 计量规则
     */
    public void setRule(String rule) {
        this.rule = rule;
    }
    /**
     * 单位
     */
    public String getUnit() {
        return unit;
    }

    /**
     * 单位
     */
    public void setUnit(String unit) {
        this.unit = unit;
    }
    /**
     * 本次计划工程量
     */
    public BigDecimal getNum() {
        return num;
    }

    /**
     * 本次计划工程量
     */
    public void setNum(BigDecimal num) {
        this.num = num;
    }

    public BigDecimal getRate() {
        return rate;
    }

    public void setRate(BigDecimal rate) {
        this.rate = rate;
    }

    /**
     * 单价(无税）
     */
    public BigDecimal getPrice() {
        return price;
    }

    /**
     * 单价(无税）
     */
    public void setPrice(BigDecimal price) {
        this.price = price;
    }
    /**
     * 单价(含税）
     */
    public BigDecimal getTaxPrice() {
        return taxPrice;
    }

    /**
     * 单价(含税）
     */
    public void setTaxPrice(BigDecimal taxPrice) {
        this.taxPrice = taxPrice;
    }
    /**
     * 金额(无税）
     */
    public BigDecimal getMny() {
        return mny;
    }

    /**
     * 金额(无税）
     */
    public void setMny(BigDecimal mny) {
        this.mny = mny;
    }
    /**
     * 金额(含税）
     */
    public BigDecimal getTaxMny() {
        return taxMny;
    }

    /**
     * 金额(含税）
     */
    public void setTaxMny(BigDecimal taxMny) {
        this.taxMny = taxMny;
    }
    /**
     * 税额
     */
    public BigDecimal getTax() {
        return tax;
    }

    /**
     * 税额
     */
    public void setTax(BigDecimal tax) {
        this.tax = tax;
    }
    /**
     * 备注
     */
    public String getMemo() {
        return memo;
    }

    /**
     * 备注
     */
    public void setMemo(String memo) {
        this.memo = memo;
    }
    
}
